#!/bin/bash

# Script to delete tiles that only contain water (usually in the
# middle of an ocean) in the higher numbered zoomlevels. These
# are trivial to regenerate (far less than one second) at any
# time.

# Some settings
# Minimum Zoom in which we delete
MINZ=10

# Maximum Zoom in which we delete
MAXZ=20

# Age in days after which we delete
AGE=3

declare -A TMD5
# the md5sum of a metatile containing only water?
TMD5[osmde]="c6501cefd852a2c5b16f297948ca309c"
TMD5[osmorg]="9d7ceeb7ab3a0905abf200f1a7608f92"
TMD5[osmhd]="d47bd18df80dbefb2f89b81a672cae92"

declare -A TSIZE
# the size of a metatile containing only water?
TSIZE[osmde]=7124
TSIZE[osmorg]=7124
TSIZE[osmhd]=8596

declare -A TDIR
# Directory that contains the tiles? (with trailing slash!)
TDIR[osmde]="/mnt/tiles/tiles/osmde/"
TDIR[osmorg]="/mnt/tiles/tiles/osm/"
TDIR[osmhd]="/mnt/tiles/tiles/osmhd/"

NDELETED=0
for style in "osmde" "osmorg" "osmhd"
do
  echo "Handling style: $style - looking for files with size ${TSIZE[$style]} and md5sum ${TMD5[$style]} in ${TDIR[$style]}"
  for z in `seq $MINZ $MAXZ`
  do
    if [ ! -d "${TDIR[$style]}${z}" ] ; then
      continue
    fi
    for tiles in `find ${TDIR[$style]}${z} -xdev -type f -name '*.meta' -size ${TSIZE[$style]}c -mtime +${AGE} -print`
    do
      # We need to skip the first 20 bytes of the file as they contain the metafile
      # header that contains the x/y location of the tile.
      TILEMD5=`tail -c +20 $tiles | md5sum -b | sed -e 's/ .*//g'`
      if [ "$TILEMD5" == "${TMD5[$style]}" ] ; then
        echo "Deleting $tiles"
        rm $tiles
        if [ $? -ne 0 ] ; then
          echo "There was an error deleting $tiles."
          echo "Aborting after deleting $NDELETED files."
          exit 1
        fi
        let "NDELETED=NDELETED+1"
      #else
      #  echo "$tiles is not a water tile."
      fi
    done
  done
done

echo "$NDELETED files deleted."

